@@ -359,7 +359,7 @@ fn test_no_defaults() {
             &RUN_TIME.to_string(),
             "--requests-file",
             &requests_file,
-            "--metrics-format",
+            "--requests-format",
             LOG_FORMAT,
             "--debug-file",
             &debug_file,
@@ -431,7 +431,7 @@ fn test_no_defaults_gaggle() {
                 &PORT.to_string(),
                 "--requests-file",
                 &worker_requests_file,
-                "--metrics-format",
+                "--requests-format",
                 LOG_FORMAT,
                 "--debug-file",
                 &worker_debug_file,
